@@ -1,7 +1,7 @@
 
 # Main function used to produce basic summary statistics; called by microsynth()
-get.stats <- function(bigdat, w, inter, keep.groups, result.var = dimnames(bigdat)[[2]], end.pre, 
-    period = 1, end.post = 80, file = NULL, sep = TRUE, start.pre = 25, legend.spot = "bottomleft", 
+get.stats <- function(bigdat, w, inter, keep.groups, result.var = dimnames(bigdat)[[2]], 
+    end.pre, period = 1, end.post = 80, file = NULL, sep = TRUE, start.pre = 25, legend.spot = "bottomleft", 
     omnibus.var = result.var, cut.mse = 1, scale.var = "Intercept", twosided = FALSE, time.names = NULL) {
     if (length(time.names) == 0) {
         time.names <- as.character(1:dim(bigdat)[3])
@@ -77,8 +77,8 @@ get.stats <- function(bigdat, w, inter, keep.groups, result.var = dimnames(bigda
         stat4[i, use.cols] <- rowSums(test1[result.var, fuse, drop = FALSE])
         stat5[i, use.cols] <- rowSums(test2[result.var, fuse, drop = FALSE])
         stat1[i, use.cols] <- stat4[i, use.cols, drop = FALSE] - stat5[i, use.cols, drop = FALSE]
-        stat2[i, use.cols] <- stat1[i, use.cols, drop = FALSE]/rowSums(test2[result.var, fuse, 
-            drop = FALSE])
+        stat2[i, use.cols] <- stat1[i, use.cols, drop = FALSE]/rowSums(test2[result.var, 
+            fuse, drop = FALSE])
         if (length(plot.it) > 0) {
             if (i == 1) {
                 plotdat.t[plot.it, ] <- test1[plot.it, ]
@@ -101,8 +101,8 @@ get.stats <- function(bigdat, w, inter, keep.groups, result.var = dimnames(bigda
             }
         }
     }
-    stats <- list(stat1[keep, , drop = FALSE], stat2[keep, , drop = FALSE], stat4[keep, , 
-        drop = FALSE], stat5[keep, , drop = FALSE], list(Treatment = plotdat.t, Control = plotdat.c, 
+    stats <- list(stat1[keep, , drop = FALSE], stat2[keep, , drop = FALSE], stat4[keep, 
+        , drop = FALSE], stat5[keep, , drop = FALSE], list(Treatment = plotdat.t, Control = plotdat.c, 
         All = plotdat.a, Difference = plotdat.d, end.pre = end.pre, scale.by = scale.by))
     return(stats)
 }
@@ -407,8 +407,8 @@ get.stats1 <- function(bigdat, w, inter, keep.groups, all.var, end.pre, period =
                 }
                 tmp.boot <- proc.time() - tmp.boot
                 if (printFlag) {
-                  message("Completed survey statistics for permutation groups: Time = ", round(tmp.boot[3], 
-                    2), "\n", sep = "", appendLF = FALSE)
+                  message("Completed survey statistics for permutation groups: Time = ", 
+                    round(tmp.boot[3], 2), "\n", sep = "", appendLF = FALSE)
                 }
             }
             if (is.inf) {
@@ -455,8 +455,8 @@ get.stats1 <- function(bigdat, w, inter, keep.groups, all.var, end.pre, period =
 
 # Sub-function of get.stats1()
 get.stats1.sub <- function(X, G, use.jack, boot.upper, boot.lower, inter, w, end.post, end.pre, 
-    period, bigdat, all.var, use.omnibus, omnibus.var, two.sided, test, use.test, time, time.tmp1, 
-    reps, keep.var, twosided, printFlag, tmp.boot, all.nams1) {
+    period, bigdat, all.var, use.omnibus, omnibus.var, two.sided, test, use.test, time, 
+    time.tmp1, reps, keep.var, twosided, printFlag, tmp.boot, all.nams1) {
     
     i <- X
     G.tmp <- G
@@ -520,8 +520,8 @@ get.stats1.sub <- function(X, G, use.jack, boot.upper, boot.lower, inter, w, end
             design <- survey::svydesign(ids = ~0, data = test.tmp, weights = w.tmp)
         } else {
             sup.out <- suppressWarnings({
-                design <- survey::svrepdesign(data = test.tmp, repweights = w.jack.tmp, weights = w.tmp, 
-                  combined.weights = TRUE, type = "JK1", mse = TRUE)
+                design <- survey::svrepdesign(data = test.tmp, repweights = w.jack.tmp, 
+                  weights = w.tmp, combined.weights = TRUE, type = "JK1", mse = TRUE)
             })
         }
         usevars <- colnames(test.tmp)
@@ -637,7 +637,8 @@ get.stats1.sub <- function(X, G, use.jack, boot.upper, boot.lower, inter, w, end
         Sigma <- Sigma[keep.var, keep.var, drop = FALSE]
         if (!twosided) {
             a <- as.matrix(diag(Sigma)^-0.5)
-            stat1.out[length(stat1.out)] <- crossprod(a, thetas)/sqrt(t(a) %*% Sigma %*% a)
+            stat1.out[length(stat1.out)] <- crossprod(a, thetas)/sqrt(t(a) %*% Sigma %*% 
+                a)
         } else {
             stat1.out[length(stat1.out)] <- crossprod(thetas, solve(Sigma)) %*% thetas
         }
@@ -656,13 +657,14 @@ get.stats1.sub <- function(X, G, use.jack, boot.upper, boot.lower, inter, w, end
         }
         if (is.inf) {
             if (printFlag) {
-                message("WARNING: Infinite standard errors yielded by main weights.\n", appendLF = FALSE)
+                message("WARNING: Infinite standard errors yielded by main weights.\n", 
+                  appendLF = FALSE)
             }
         }
     } else if (is.jack) {
         if (printFlag) {
-            message("Completed survey statistics for jackknife: Time = ", round(tmp[3], 2), 
-                "\n", sep = "", appendLF = FALSE)
+            message("Completed survey statistics for jackknife: Time = ", round(tmp[3], 
+                2), "\n", sep = "", appendLF = FALSE)
         }
         if (boot > 0) {
             if (printFlag) {
